@@ -135,7 +135,8 @@ int _alpm_trans_addtarget(pmtrans_t *trans, char *target)
 	ASSERT(target != NULL, RET_ERR(PM_ERR_WRONG_ARGS, -1));
 
 	if(alpm_list_find_str(trans->targets, target)) {
-		RET_ERR(PM_ERR_TRANS_DUP_TARGET, -1);
+		return(0);
+		//RET_ERR(PM_ERR_TRANS_DUP_TARGET, -1);
 	}
 
 	switch(trans->type) {
